### Install RSeQC using [pip](https://pip.pypa.io/en/stable/)

 `$ pip install rseqc`

### Upgrade

 `$ pip install rseqc --upgrade`

### Uninstall
 `pip -y uninstall rseqc`

### Documentation

http://rseqc.sourceforge.net/

